@@ -10,6 +10,7 @@
 #' \code{getOption("fsl.path")}, it will try the default directory \code{/usr/local/fsl}.
 #' @return NULL if FSL in path, or bash code for setting up FSL DIR
 #' @export
+#' @import neurobase
 get.fsl = function(add_bin = TRUE){
   cmd = NULL
   fsldir = Sys.getenv("FSLDIR")
@@ -57,6 +58,13 @@ get.fsl = function(add_bin = TRUE){
   return(cmd)
 }
 
+#' @rdname get.fsl
+#' @aliases get_fsl
+#' @export
+get_fsl = function(add_bin = TRUE){
+  return(get.fsl(add_bin = add_bin))
+}
+
 
 #' @title Get FSL's Directory 
 #' @description Finds the FSLDIR from system environment or \code{getOption("fsl.path")}
@@ -92,6 +100,14 @@ have.fsl = function(...){
   return(!inherits(x, "try-error"))
 }
 
+#' @rdname have.fsl
+#' @aliases have_fsl
+#' @export
+have_fsl = function(...){
+  return(have.fsl(...))
+}
+
+
 #' @name get.fsloutput
 #' @title Determine FSL output type
 #' @description Finds the FSLOUTPUTTYPE from system environment or 
@@ -1207,54 +1223,6 @@ fslbet.help = function(betcmd = c("bet2", "bet")){
 }
 
 
-#' @title Image Center of Gravity
-#' @description Find Center of Gravity of Image, after thresholding
-#' @param img Object of class nifti
-#' @param thresh threshold for image, will find \code{img > 0}
-#' @param ceil Run \code{\link{ceiling}} to force integers (usu for plotting)
-#' @param warn Produce a warning if the image is empty after thresholding
-#' @return Vector of length 3
-#' @export
-#' @examples
-#' if (have.fsl()){
-#' x = array(rnorm(1e6), dim = c(100, 100, 100))
-#' img = nifti(x, dim= c(100, 100, 100), 
-#' datatype = convert.datatype()$FLOAT32, cal.min = min(x), 
-#' cal.max = max(x), pixdim = rep(1, 4))
-#' cog(img)
-#' } 
-cog = function(img, thresh = 0, ceil = FALSE, warn = TRUE){
-  #   stopifnot(inherits(img, "nifti"))
-  mask = img > thresh
-  if (sum(mask, na.rm = TRUE) == 0) {
-    if (warn) {
-      warning(paste0("No voxels found to be > ", round(thresh, 3), 
-                     ", using the center of whole image"))
-    }
-    xyz = dim(mask) / 2
-  } else {
-    xyz = colMeans(which(mask, arr.ind = TRUE))
-  }
-  if (ceil) xyz = ceiling(xyz)
-  return(xyz)
-}
-
-
-
-#' @title Image Center of Gravity Wrapper
-#' @description Find Center of Gravity of Image, after thresholding and
-#' take ceiling (wrapper for \code{\link{cog}})
-#' @param ... Arguments ppssed to \code{\link{cog}}
-#' @return Vector of length 3
-#' @note Just a convenience wrapper for \code{cog(ceil=TRUE)}
-#' @export
-xyz = function(...){
-  xyz = cog(..., ceil = TRUE)
-  return(xyz)
-}
-
-
-
 #' @title Image Center of Gravity (FSL)
 #' @description Find Center of Gravity of Image from FSL
 #' @param img Object of class nifti, or path of file
